import { ColorPicker } from './../index';
import { Animation, ColorApplyValueMode, ColorDisplayMode, DropDownOpenMode, DropDownButtonPosition, DropDownPosition, ColorPalette, ResizeMode, ColorTooltipDisplayMode, ColorValueFormat, ColorValueDisplayMode } from './../index';
import { AfterViewInit, ElementRef, OnInit, OnChanges, OnDestroy, SimpleChanges, EventEmitter } from '@angular/core';
import { BaseElement } from './smart.element';
import { ControlValueAccessor } from '@angular/forms';
import * as i0 from "@angular/core";
export { Animation, ColorApplyValueMode, ColorDisplayMode, DropDownOpenMode, DropDownButtonPosition, DropDownPosition, ColorPalette, ResizeMode, ColorTooltipDisplayMode, ColorValueFormat, ColorValueDisplayMode, ElementRenderMode } from './../index';
export { Smart } from './smart.element';
export { ColorPicker } from './../index';
export declare class ColorPickerComponent extends BaseElement implements OnInit, AfterViewInit, OnDestroy, OnChanges, ControlValueAccessor {
    constructor(ref: ElementRef<ColorPicker>);
    private eventHandlers;
    nativeElement: ColorPicker;
    /** @description Creates the component on demand.
     * @param properties An optional object of properties, which will be added to the template binded ones.
     */
    createComponent(properties?: {}): any;
    /**
    * @description
    * The registered callback function called when a change event occurs on the form elements.
    */
    _onChange: (value: any) => void;
    /**
    * @description
    * The registered callback function called when a blur event occurs on the form elements.
    */
    _onTouched: () => any;
    /** @description Sets or gets the animation mode. Animation is disabled when the property is set to 'none' */
    get animation(): Animation | string;
    set animation(value: Animation | string);
    /** @description This property allows editting of colors via the input inside the element's action section. Accepts values in all supported types. This property works when 'valueDisplayMode' is set to default or colorCode. */
    get editable(): boolean;
    set editable(value: boolean);
    /** @description Determines the delay before the opened drop down closes when dropDownOpenMode is set to 'auto'. */
    get autoCloseDelay(): number;
    set autoCloseDelay(value: number);
    /** @description Specifies how the user applies the selected value. In 'instantly' mode the value is applied immediately when color is selected. In 'useButtons' mode are shown 'Ok' and 'Cancel' buttons at the botom of the colorpicker's drop down. Only click on 'OK' button applies the value. */
    get applyValueMode(): ColorApplyValueMode | string;
    set applyValueMode(value: ColorApplyValueMode | string);
    /** @description Defines the number of columns for the colors in displayModes 'grid', 'hexagonal' and 'spectrumGrid'. */
    get columnCount(): number;
    set columnCount(value: number);
    /** @description Determines the colors that will be displayed and their layout. */
    get displayMode(): ColorDisplayMode | string;
    set displayMode(value: ColorDisplayMode | string);
    /** @description Enables or disables the element. */
    get disabled(): boolean;
    set disabled(value: boolean);
    /** @description By default clicking on color panel's preview container returns the color value to it's previous state. 'disableUndo' prevents this functionality. */
    get disableUndo(): boolean;
    set disableUndo(value: boolean);
    /** @description Sets the parent container of the dropDown (the popup). The expected value is CSS Selector, ID or 'body'. Used when a CSS property of unknowned parent is interfering with the visibility of the dropDown. Example: 'body'. */
    get dropDownAppendTo(): string;
    set dropDownAppendTo(value: string);
    /** @description Determines how the drop down is going to open. */
    get dropDownOpenMode(): DropDownOpenMode | string;
    set dropDownOpenMode(value: DropDownOpenMode | string);
    /** @description Determines the position of the drop down button. */
    get dropDownButtonPosition(): DropDownButtonPosition | string;
    set dropDownButtonPosition(value: DropDownButtonPosition | string);
    /** @description Determines the vertical position of the dropDown. 'Auto' means its automatically determined depending on the viewport size. */
    get dropDownPosition(): DropDownPosition | string;
    set dropDownPosition(value: DropDownPosition | string);
    /** @description Sets the height of the drop down. Default value of null means that CSS variables are used. This property should be used when the browser doesn not support CSS variables. */
    get dropDownHeight(): string;
    set dropDownHeight(value: string);
    /** @description If this property is enabled, when the element's dropdown is opened, a transparent overlay is positioned between the dropdown and the rest of the document. */
    get dropDownOverlay(): boolean;
    set dropDownOverlay(value: boolean);
    /** @description Sets the width of the drop down. Default value of null means that CSS variables are used. This property should be used when the browser doesn't support CSS variables. */
    get dropDownWidth(): string;
    set dropDownWidth(value: string);
    /** @description Allows to edit the alpha(transparency) of the colors via an editor/slider in the following displayModes: 'palette', 'radial', 'hexagonal' */
    get editAlphaChannel(): boolean;
    set editAlphaChannel(value: boolean);
    /** @description Allows to select a custom color via an editor popup. Custom color selection is available in modes that don't have this option by default, like: 'grid', 'default, 'spectrum grid'. */
    get enableCustomColors(): boolean;
    set enableCustomColors(value: boolean);
    /** @description Defines an Array of colors that will be used as the Theme Colors in the corresponding section of displayMode: 'grid' and 'default'. */
    get gridThemeColors(): string[] | null;
    set gridThemeColors(value: string[] | null);
    /** @description Defines an Array of colors that will be used as the Shade Colors in the corresponding section of displayMode: 'grid' and 'default'. */
    get gridShadeColors(): string[] | null;
    set gridShadeColors(value: string[] | null);
    /** @description Defines an Array of colors that will be used as the Standart Colors in the corresponding section of displayMode: 'grid' and 'default'. */
    get gridStandardColors(): string[] | null;
    set gridStandardColors(value: string[] | null);
    /** @description Hides the alpha editor. Alpha editor is an input containing the value of the current color opacity. The input is available in the following modes: 'radial', 'palette', 'hexagonal'. The input is only visible if there's enough space. This editor is visible by default. */
    get hideAlphaEditor(): boolean;
    set hideAlphaEditor(value: boolean);
    /** @description Determines which color editors will be hidden first when there's not enough space for all of them to be visible. By default the editors are only visible in 'palette', 'radial' and 'hexagonal' display modes. This property allows to prioritize the visibility of the editors. */
    get hideContentToFit(): string[];
    set hideContentToFit(value: string[]);
    /** @description HEX editor is an input containing the hexadecimal representation of a color. This editor is visible by default. Setting 'hideRGBeditor' to true hides it. */
    get hideHEXEditor(): boolean;
    set hideHEXEditor(value: boolean);
    /** @description Hides the preview container. Preview container is used to show the currently selected value in 'palette', 'radial' and 'hexagonal' display modes. */
    get hidePreviewContainer(): boolean;
    set hidePreviewContainer(value: boolean);
    /** @description Hides the RGB editor. This editor is a group of three separate inputs for the Red, Green and Blue values of the color. */
    get hideRGBEditor(): boolean;
    set hideRGBEditor(value: boolean);
    /** @description Sets additional helper text below the element that is only visible when the element is focused. */
    get hint(): string;
    set hint(value: string);
    /** @description Inverts the colors in 'spectrumGrid', 'hexagonal', 'radial' modes. */
    get inverted(): boolean;
    set inverted(value: boolean);
    /** @description Sets a label above the element. */
    get label(): string;
    set label(value: string);
    /** @description Sets or gets the language. Used in conjunction with the property messages.  */
    get locale(): string;
    set locale(value: string);
    /** @description Callback used to customize the format of the messages that are returned from the Localization Module. */
    get localizeFormatFunction(): any;
    set localizeFormatFunction(value: any);
    /** @description Sets or gets an object specifying strings used in the widget that can be localized. Used in conjunction with the property locale.  */
    get messages(): any;
    set messages(value: any);
    /** @description Sets or gets the name attribute for the element. Name is used when submiting HTML forms. */
    get name(): string;
    set name(value: string);
    /** @description Determines whether the popup is opened or closed */
    get opened(): boolean;
    set opened(value: boolean);
    /** @description Determines what colors will be displayed in 'spectrumGrid', 'grid' and 'hexagonal' displayModes. */
    get palette(): ColorPalette | string;
    set palette(value: ColorPalette | string);
    /** @description Defines an array of colors that form a custom palette. This palette can be used in displayModes 'grid' and 'spectrum grid' if the palette property is set to custom. The value of the property can be an array of strings or objects that contain valid colors ( HEX, RGBA, etc). */
    get paletteColors(): {
        name: string;
        value: string;
    }[] | string[] | null;
    set paletteColors(value: {
        name: string;
        value: string;
    }[] | string[] | null);
    /** @description Defines an array of colors that represent a predefined list of custom colors. This palette can be used in displayModes 'grid', 'default' and 'spectrum grid'. Custom colors are displayed at the bottom of the color grid below the button for custom color selection. They are only visible if enableCustomColor property is true. */
    get paletteCustomColors(): string[] | null;
    set paletteCustomColors(value: string[] | null);
    /** @description The placeholder is shown when the value is not set yet or is set to null. */
    get placeholder(): string;
    set placeholder(value: string);
    /** @description Disables user interaction with the element. */
    get readonly(): boolean;
    set readonly(value: boolean);
    /** @description Determines whether the resize indicator in the bottom right corner of the drop down is visible or not. This property is used in conjunction with resizeMode. */
    get resizeIndicator(): boolean;
    set resizeIndicator(value: boolean);
    /** @description Determines whether the dropDown can be resized or not. When resizing is enabled, a resize bar appears on the top/bottom side of the drop down. */
    get resizeMode(): ResizeMode | string;
    set resizeMode(value: ResizeMode | string);
    /** @description Sets or gets the value indicating whether the element is aligned to support locales using right-to-left fonts. */
    get rightToLeft(): boolean;
    set rightToLeft(value: boolean);
    /** @description Determines the theme. Theme defines the look of the element */
    get theme(): string;
    set theme(value: string);
    /** @description Determines how the tooltip displays the value of the color that is being hovered. */
    get tooltipDisplayMode(): ColorTooltipDisplayMode | string;
    set tooltipDisplayMode(value: ColorTooltipDisplayMode | string);
    /** @description If is set to true, the element cannot be focused. */
    get unfocusable(): boolean;
    set unfocusable(value: boolean);
    /** @description Represents the value of the selected color as the value of the element. */
    get value(): string;
    set value(value: string);
    /** @description Determines the format of the color. Whether it's in HEX, RGB or RGBA. By default it shows the color depending on the displayMode. */
    get valueFormat(): ColorValueFormat | string;
    set valueFormat(value: ColorValueFormat | string);
    /** @description Determines which elements will be displayed in color picker's action section. */
    get valueDisplayMode(): ColorValueDisplayMode | string;
    set valueDisplayMode(value: ColorValueDisplayMode | string);
    /** @description This event is triggered when user clicks on the action button. 'Ok' button is visible only when applyValueMode is set to useButtons.
    *  @param event. The custom event. 	*/
    onActionButtonClick: EventEmitter<CustomEvent>;
    /** @description This event is triggered when the cancel button is clicked. 'Cancel' button is visible only when applyValueMode is set to useButtons.
    *  @param event. The custom event. 	*/
    onCancelButtonClick: EventEmitter<CustomEvent>;
    /** @description This event is triggered when the color value is changed.
    *  @param event. The custom event. 	Custom event was created with: event.detail(	oldValue, 	value)
    *   oldValue - The previously selected color.
    *   value - The new selected color.
    */
    onChange: EventEmitter<CustomEvent>;
    /** @description This event is triggered when the drop down is closed.
    *  @param event. The custom event. 	*/
    onClose: EventEmitter<CustomEvent>;
    /** @description This event is triggered when the drop down is about to be closed. This event allows to cancel the closing operation calling event.preventDefault() in the event handler function.
    *  @param event. The custom event. 	*/
    onClosing: EventEmitter<CustomEvent>;
    /** @description This event is triggered when the custom color selection view is opened/closed. Custom color selection view is available when enableCustomColors property is true.
    *  @param event. The custom event. 	Custom event was created with: event.detail(	value)
    *   value - A boolean that indicates whether the custom color view is shown or not.
    */
    onCustomColorSelection: EventEmitter<CustomEvent>;
    /** @description This event is triggered when user clicks on the drop down button.
    *  @param event. The custom event. 	*/
    onDropDownButtonClick: EventEmitter<CustomEvent>;
    /** @description This event is triggered when the ok button is clicked.
    *  @param event. The custom event. 	*/
    onOkButtonClick: EventEmitter<CustomEvent>;
    /** @description This event is triggered when the drop down is opened.
    *  @param event. The custom event. 	*/
    onOpen: EventEmitter<CustomEvent>;
    /** @description This event is triggered when the drop down is about to be opened. This event allows to cancel the opening operation calling event.preventDefault() in the event handler function.
    *  @param event. The custom event. 	*/
    onOpening: EventEmitter<CustomEvent>;
    /** @description This event is triggered when user starts resizing the drop down.
    *  @param event. The custom event. 	Custom event was created with: event.detail(	position)
    *   position - An object containing the current left and top positions of the drop down.
    */
    onResizeStart: EventEmitter<CustomEvent>;
    /** @description This event is triggered when the resizing of the drop down is finished.
    *  @param event. The custom event. 	Custom event was created with: event.detail(	position)
    *   position - An object containing the current left and top positions of the drop down.
    */
    onResizeEnd: EventEmitter<CustomEvent>;
    /** @description Opens the drop down of the color picker.
    */
    open(): void;
    /** @description Closes the drop down of the color picker.
    */
    close(): void;
    get isRendered(): boolean;
    ngOnInit(): void;
    ngAfterViewInit(): void;
    ngOnDestroy(): void;
    _initialChange: boolean;
    get ngValue(): any;
    set ngValue(value: any);
    writeValue(value: any): void;
    registerOnChange(fn: any): void;
    registerOnTouched(fn: any): void;
    ngOnChanges(changes: SimpleChanges): void;
    /** @description Add event listeners. */
    private listen;
    /** @description Remove event listeners. */
    private unlisten;
    static ɵfac: i0.ɵɵFactoryDeclaration<ColorPickerComponent, never>;
    static ɵdir: i0.ɵɵDirectiveDeclaration<ColorPickerComponent, "smart-color-picker, [smart-color-picker]", ["smart-color-picker"], { "animation": "animation"; "editable": "editable"; "autoCloseDelay": "autoCloseDelay"; "applyValueMode": "applyValueMode"; "columnCount": "columnCount"; "displayMode": "displayMode"; "disabled": "disabled"; "disableUndo": "disableUndo"; "dropDownAppendTo": "dropDownAppendTo"; "dropDownOpenMode": "dropDownOpenMode"; "dropDownButtonPosition": "dropDownButtonPosition"; "dropDownPosition": "dropDownPosition"; "dropDownHeight": "dropDownHeight"; "dropDownOverlay": "dropDownOverlay"; "dropDownWidth": "dropDownWidth"; "editAlphaChannel": "editAlphaChannel"; "enableCustomColors": "enableCustomColors"; "gridThemeColors": "gridThemeColors"; "gridShadeColors": "gridShadeColors"; "gridStandardColors": "gridStandardColors"; "hideAlphaEditor": "hideAlphaEditor"; "hideContentToFit": "hideContentToFit"; "hideHEXEditor": "hideHEXEditor"; "hidePreviewContainer": "hidePreviewContainer"; "hideRGBEditor": "hideRGBEditor"; "hint": "hint"; "inverted": "inverted"; "label": "label"; "locale": "locale"; "localizeFormatFunction": "localizeFormatFunction"; "messages": "messages"; "name": "name"; "opened": "opened"; "palette": "palette"; "paletteColors": "paletteColors"; "paletteCustomColors": "paletteCustomColors"; "placeholder": "placeholder"; "readonly": "readonly"; "resizeIndicator": "resizeIndicator"; "resizeMode": "resizeMode"; "rightToLeft": "rightToLeft"; "theme": "theme"; "tooltipDisplayMode": "tooltipDisplayMode"; "unfocusable": "unfocusable"; "value": "value"; "valueFormat": "valueFormat"; "valueDisplayMode": "valueDisplayMode"; }, { "onActionButtonClick": "onActionButtonClick"; "onCancelButtonClick": "onCancelButtonClick"; "onChange": "onChange"; "onClose": "onClose"; "onClosing": "onClosing"; "onCustomColorSelection": "onCustomColorSelection"; "onDropDownButtonClick": "onDropDownButtonClick"; "onOkButtonClick": "onOkButtonClick"; "onOpen": "onOpen"; "onOpening": "onOpening"; "onResizeStart": "onResizeStart"; "onResizeEnd": "onResizeEnd"; }, never>;
}
